==> zio-aws-backup_2.12-5.17.129.2-sources.jar: zio/aws/backup/model/DescribeBackupVaultRequest.scala <==
package zio.aws.backup.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeBackupVaultRequest(backupVaultName: String) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backup.model.DescribeBackupVaultRequest = {
    import DescribeBackupVaultRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backup.model.DescribeBackupVaultRequest
      .builder()
      .backupVaultName(backupVaultName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.backup.model.DescribeBackupVaultRequest.ReadOnly =
    zio.aws.backup.model.DescribeBackupVaultRequest.wrap(buildAwsValue())
}
object DescribeBackupVaultRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backup.model.DescribeBackupVaultRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.backup.model.DescribeBackupVaultRequest =
      zio.aws.backup.model.DescribeBackupVaultRequest(backupVaultName)
    def backupVaultName: String
    def getBackupVaultName: ZIO[Any, Nothing, String] =
      ZIO.succeed(backupVaultName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backup.model.DescribeBackupVaultRequest
  ) extends zio.aws.backup.model.DescribeBackupVaultRequest.ReadOnly {
    override val backupVaultName: String = impl.backupVaultName(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.backup.model.DescribeBackupVaultRequest
  ): zio.aws.backup.model.DescribeBackupVaultRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-backup_2.13-7.21.15.13-sources.jar: zio/aws/backup/model/DescribeBackupVaultRequest.scala <==
package zio.aws.backup.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeBackupVaultRequest(
    backupVaultName: String,
    backupVaultAccountId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backup.model.DescribeBackupVaultRequest = {
    import DescribeBackupVaultRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backup.model.DescribeBackupVaultRequest
      .builder()
      .backupVaultName(backupVaultName: java.lang.String)
      .optionallyWith(
        backupVaultAccountId.map(value => value: java.lang.String)
      )(_.backupVaultAccountId)
      .build()
  }
  def asReadOnly: zio.aws.backup.model.DescribeBackupVaultRequest.ReadOnly =
    zio.aws.backup.model.DescribeBackupVaultRequest.wrap(buildAwsValue())
}
object DescribeBackupVaultRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backup.model.DescribeBackupVaultRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.backup.model.DescribeBackupVaultRequest =
      zio.aws.backup.model.DescribeBackupVaultRequest(
        backupVaultName,
        backupVaultAccountId.map(value => value)
      )
    def backupVaultName: String
    def backupVaultAccountId: Optional[String]
    def getBackupVaultName: ZIO[Any, Nothing, String] =
      ZIO.succeed(backupVaultName)
    def getBackupVaultAccountId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("backupVaultAccountId", backupVaultAccountId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backup.model.DescribeBackupVaultRequest
  ) extends zio.aws.backup.model.DescribeBackupVaultRequest.ReadOnly {
    override val backupVaultName: String = impl.backupVaultName(): String
    override val backupVaultAccountId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.backupVaultAccountId())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.backup.model.DescribeBackupVaultRequest
  ): zio.aws.backup.model.DescribeBackupVaultRequest.ReadOnly = new Wrapper(
    impl
  )
}
